.. _modules:

==============
API References
==============

This is the class and function reference of biolearn. Please refer to
the :ref:`user guide <user_guide>` for more information and usage examples.

.. toctree::
   :hidden:

   load.rst
   data_library.rst
   model_gallery.rst
   imputation.rst